@@ -21,6 +21,7 @@
 
 #include "atm.h"
 #include "atmd.h"
+#include "atmarpd.h"
 
 #include "table.h"
 #include "itf.h"
@@ -498,13 +499,15 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 	}
     if (!atmsvc_addr_in_use(*addr)) addr = NULL;
     if (entry->addr && addr && (entry->flags & ATF_PERM) &&
-      !atm_equal(entry->addr,addr,0,0)) {
+      !atm_equal((struct sockaddr *) entry->addr,(struct sockaddr *) addr,0,0))
+      {
 	diag(COMPONENT,DIAG_ERROR,"ignoring attempt to change ATM address of "
 	  "permanent entry");
 	return;
     }
     if (entry->state == as_valid && entry->ip == ip && (!addr || (entry->addr
-      && atm_equal(entry->addr,addr,0,0)))) return; /* no news */
+      && atm_equal((struct sockaddr *) entry->addr,(struct sockaddr *) addr,0,
+      0)))) return; /* no news */
     STOP_TIMER(entry);
     entry->ip = ip;
     if (!entry->itf) {
@@ -835,68 +838,56 @@ static int ioctl_delete(ITF *itf,uint32_t ip,int flags)
 }
 
 
-int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
+int arp_ioctl(struct atmarp_req *req)
 {
     ITF *itf;
     char buffer[MAX_ATM_ADDR_LEN+1];
-    uint32_t ip;
     unsigned char *ipp;
 
-    diag(COMPONENT,DIAG_DEBUG,"arp_ioctl 0x%08lx",cmd);
-    if (req->arp_pa.sa_family != AF_INET) {
-	diag(COMPONENT,DIAG_ERROR,"SIOCxARP: bad PA AF 0x%x",
-	  req->arp_pa.sa_family);
-	return -EPFNOSUPPORT;
-    }
-    ip = ((struct sockaddr_in *) &req->arp_pa)->sin_addr.s_addr;
-    ipp = (unsigned char *) &ip;
-    if (!(itf = lookup_itf(itf_num))) {
-	diag(COMPONENT,DIAG_ERROR,"itf %d not found",itf_num);
-	return -EPROTO;
-    }
-    switch (cmd) {
-	case SIOCSARP:
-	    if (req->arp_flags & ATF_DEFQOS) {
-		diag(COMPONENT,DIAG_DEBUG,"got SIOCSARP ATF_DEFQOS for itf %d",
-		  itf_num);
-		itf->qos = req->arp_qos;
-		return 0;
-	    }
+    diag(COMPONENT,DIAG_DEBUG,"arp_ioctl %d",req->type);
+    itf = lookup_itf_by_ip(req->ip);
+    if (!itf) return -EHOSTUNREACH;
+    if (!(req->ip & ~itf->netmask) && !(req->flags & ATF_ARPSRV) &&
+	req->type != art_qos) return -EADDRNOTAVAIL;
+    ipp = (unsigned char *) &req->ip;
+    switch (req->type) {
+	case art_qos:
+	    diag(COMPONENT,DIAG_DEBUG,"got art_qos for itf %d",itf->number);
+	    itf->qos = req->qos;
+	    return 0;
+	case art_set:
 	    if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,
-	      (struct sockaddr *) &req->arp_ha,pretty) < 0) {
-		diag(COMPONENT,DIAG_ERROR,"a2t fails on SIOCSARP");
+	      (struct sockaddr *) &req->addr,pretty) < 0) {
+		diag(COMPONENT,DIAG_ERROR,"a2t fails on art_set");
 		return -EINVAL;
 	    }
-	    diag(COMPONENT,DIAG_DEBUG,"got SIOCSARP for itf %d, IP %d.%d.%d.%d"
-	      ", ATM %s, flags 0x%x",itf_num,ipp[0],ipp[1],ipp[2],ipp[3],buffer,
-	      req->arp_flags);
-	    if (!req->arp_qos.txtp.traffic_class &&
-	      !req->arp_qos.rxtp.traffic_class) req->arp_qos = itf->qos;
-	    switch (req->arp_ha.sas_family) {
+	    diag(COMPONENT,DIAG_DEBUG,"got art_set for itf %d, IP %d.%d.%d.%d"
+	      ", ATM %s, flags 0x%x",itf->number,ipp[0],ipp[1],ipp[2],ipp[3],
+	      buffer,req->flags);
+	    if (!req->qos.txtp.traffic_class && !req->qos.rxtp.traffic_class)
+		req->qos = itf->qos;
+	    switch (req->addr.sas_family) {
 		case AF_ATMPVC:	
-		    adjust_qos(itf,&req->arp_qos,req->arp_flags & ATF_NULL);
-		    return ioctl_set_pvc(itf,((struct sockaddr_in *)
-		      &req->arp_pa)->sin_addr.s_addr,(struct sockaddr_atmpvc *)
-		      &req->arp_ha,&req->arp_qos,req->arp_flags);
+		    adjust_qos(itf,&req->qos,req->flags & ATF_NULL);
+		    return ioctl_set_pvc(itf,req->ip,
+		      (struct sockaddr_atmpvc *) &req->addr,&req->qos,
+		      req->flags);
 		case AF_ATMSVC:
-		    adjust_qos(itf,&req->arp_qos,0);
-		    return ioctl_set_svc(itf,((struct sockaddr_in *)
-		      &req->arp_pa)->sin_addr.s_addr,(struct sockaddr_atmsvc *)
-		      &req->arp_ha,&req->arp_qos,req->arp_flags);
+		    adjust_qos(itf,&req->qos,0);
+		    return ioctl_set_svc(itf,req->ip,
+		      (struct sockaddr_atmsvc *) &req->addr,&req->qos,
+		      req->flags);
 		default: /* not reached - atm2text complains before */
-		    diag(COMPONENT,DIAG_ERROR,"SIOCSARP: bad HA AF 0x%x",
-		      req->arp_ha.sas_family);
+		    diag(COMPONENT,DIAG_ERROR,"art_set: bad HA AF 0x%x",
+		      req->addr.sas_family);
 		    return -EINVAL;
 	    }
-	case SIOCGARP:
-	    diag(COMPONENT,DIAG_DEBUG,"got SIOCGARP for itf %d",itf_num);
-	    return -ENOSYS;
-	case SIOCDARP:
-	    diag(COMPONENT,DIAG_DEBUG,"got SIOCDARP for itf %d, IP %d.%d.%d.%d"
-	      ,itf_num,ipp[0],ipp[1],ipp[2],ipp[3]);
-	    return ioctl_delete(itf,ip,req->arp_flags);
+	case art_delete:
+	    diag(COMPONENT,DIAG_DEBUG,"got art_delete for itf %d, IP "
+	      "%d.%d.%d.%d",itf->number,ipp[0],ipp[1],ipp[2],ipp[3]);
+	    return ioctl_delete(itf,req->ip,req->flags);
 	default:
-	    diag(COMPONENT,DIAG_ERROR,"unrecognized ioctl 0x%x",cmd);
+	    diag(COMPONENT,DIAG_ERROR,"unrecognized type %d",req->type);
 	    return -EINVAL;
     }
 }
