@@ -9,6 +9,7 @@
 #include <stdint.h>
 #include <linux/atmarp.h>
 
+#include "atmarpd.h"
 #include "table.h"
 
 
@@ -17,7 +18,7 @@ void discard_entry(ENTRY *entry);
 void vcc_detach(ENTRY *entry);
 void need_ip(int itf_num,uint32_t ip);
 void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len);
-int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req);
+int arp_ioctl(struct atmarp_req *req);
 void vcc_connected(VCC *vcc);
 void vcc_failed(VCC *vcc);
 void disconnect_vcc(VCC *vcc);
