@@ -1,6 +1,6 @@
 /* atmarpd.c - ATMARP demon */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -13,6 +13,7 @@
 
 #include "atm.h"
 #include "atmd.h"
+#include "atmarpd.h"
 
 #include "io.h"
 #include "table.h"
@@ -48,7 +49,7 @@ int main(int argc,char **argv)
 
     set_application("atmarpd");
     set_verbosity(NULL,DIAG_INFO);
-    dump_dir = DUMP_DIR;
+    dump_dir = ATMARP_DUMP_DIR;
     background = 0;
     while ((c = getopt(argc,argv,"bdD:l:mnp")) != EOF)
 	switch (c) {
@@ -79,7 +80,7 @@ int main(int argc,char **argv)
     diag(COMPONENT,DIAG_INFO,"Linux ATM ARP, version " VERSION);
     if (chdir(dump_dir) < 0)
 	diag(COMPONENT,DIAG_ERROR,"chdir %s: %s",dump_dir,strerror(errno));
-    if (debug) (void) unlink(TMP_DUMP_FILE); /* avoid confusion */
+    if (debug) (void) unlink(ATMARP_TMP_DUMP_FILE); /* avoid confusion */
     open_all();
     if (background) {
     	pid_t pid;
