@@ -23,6 +23,7 @@
 
 #include "atm.h"
 #include "atmd.h"
+#include "atmarpd.h"
 
 #include "table.h"
 #include "arp.h"
@@ -36,13 +37,13 @@
 struct timeval now;
 
 
-static int kernel,incoming,inet;
+static int kernel,incoming,inet,unix_sock;
 
 
 /* ----- kernel interface -------------------------------------------------- */
 
 
-void open_all(void)
+static void open_kernel(void)
 {
     struct sockaddr_atmsvc addr;
     struct atm_qos qos;
@@ -70,77 +71,48 @@ void open_all(void)
 	if (listen(incoming,5) < 0)
 	    diag(COMPONENT,DIAG_FATAL,"listen: %s",strerror(errno));
     }
-    else if (errno != EUNATCH)
+    else {
+	if (errno != EUNATCH)
 	    diag(COMPONENT,DIAG_FATAL,"bind: %s",strerror(errno));
-	else {
-	    diag(COMPONENT,DIAG_WARN,"SVCs are not available");
-	    (void) close(incoming);
-	    incoming = -1;
-	}
+	diag(COMPONENT,DIAG_WARN,"SVCs are not available");
+	(void) close(incoming);
+	incoming = -1;
+    }
     if ((inet = socket(PF_INET,SOCK_DGRAM,0)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
 }
 
 
-#if 1
-#define KERNEL_BUFFER_SIZE 500
-#else
-#define KERNEL_BASE_LEN (sizeof(struct atmsvc_msg)-sizeof(struct atm_blli))
-#define KERNEL_BUFFER_SIZE (sizeof(struct atmsvc_msg)+(ATM_MAX_BLLI-1)* \
-  sizeof(struct atm_blli)+1)
-#endif
-
-
 static void recv_kernel(void)
 {
-    struct atmarp_ctrl *ctrl;
-    unsigned char buffer[KERNEL_BUFFER_SIZE];
+    struct atmarp_ctrl ctrl;
     int size;
 
-    size = read(kernel,buffer,KERNEL_BUFFER_SIZE);
+    size = read(kernel,&ctrl,sizeof(ctrl));
     if (size < 0) {
 	diag(COMPONENT,DIAG_ERROR,"read kernel: %s",strerror(errno));
 	return;
     }
-    ctrl = (struct atmarp_ctrl *) buffer;
-    if (ctrl->magic != ATMARP_CTRL_MAGIC) {
-	diag(COMPONENT,DIAG_ERROR,"invalid magic number (0x%x) in kernel msg",
-	  ctrl->magic);
-	return;
-    }
-    switch (ctrl->type) {
+    switch (ctrl.type) {
 	case act_need:
-	    need_ip(ctrl->itf_num,ctrl->arg);
-	    break;
-	case act_create:
-	    ctrl->type = act_complete;
-	    ctrl->arg = itf_create(ctrl->itf_num);
-	    if (write(kernel,ctrl,sizeof(*ctrl)) < 0)
-		diag(COMPONENT,DIAG_ERROR,"write reply: %s",strerror(errno));
+	    need_ip(ctrl.itf_num,ctrl.ip);
 	    break;
 	case act_up:
-	    itf_up(ctrl->itf_num);
+	    itf_up(ctrl.itf_num);
 	    break;
 	case act_down:
-	    itf_down(ctrl->itf_num);
+	    itf_down(ctrl.itf_num);
 	    break;
 	case act_change:
-	    itf_change(ctrl->itf_num);
-	case act_ioctl:
-	    ctrl->type = act_complete;
-	    ctrl->arg = arp_ioctl(ctrl->itf_num,ctrl->arg,(struct atmarpreq *)
-	      ctrl->data);
-	    if (write(kernel,ctrl,sizeof(*ctrl)) < 0)
-		diag(COMPONENT,DIAG_ERROR,"write reply: %s",strerror(errno));
-	    break;
+	    itf_change(ctrl.itf_num);
 	default:
 	    diag(COMPONENT,DIAG_ERROR,"invalid control msg type 0x%x",
-	      ctrl->type);
+	      ctrl.type);
     }
 }
 
 
-void close_all(void)
+static void close_kernel(void)
 {
     if (incoming >= 0) (void) close(incoming);
     (void) close(kernel); /* may get major complaints from the kernel ... */
@@ -148,6 +120,64 @@ void close_all(void)
 }
 
 
+/* ----- atmarp (maintenance) interface ------------------------------------ */
+
+
+static void open_unix(void)
+{
+    unix_sock = un_create(ATMARP_SOCKET_PATH,0600);
+    if (unix_sock < 0)
+	diag(COMPONENT,DIAG_FATAL,"un_create: %s",strerror(errno));
+}
+
+
+static int got_unix(void *buf,int len,void *user)
+{
+    struct atmarp_req *req = buf;
+    int *reply = buf;
+
+    if (len != sizeof(*req)) {
+	diag(COMPONENT,DIAG_ERROR,"bad unix read: %d != %d",len,sizeof(*req));
+	return 0;
+    }
+    switch (req->type) {
+	case art_create:
+	    *reply = ioctl(kernel,SIOCMKCLIP,req->itf);
+	    if (*reply >= 0) itf_create(*reply);
+	    break;
+	case art_qos:
+	case art_set:
+	case art_delete:
+	    *reply = arp_ioctl(req);
+	    break;
+	case art_table:
+	    *reply = table_update();
+	    break;
+	default:
+	    diag(COMPONENT,DIAG_ERROR,"invalid request msg type 0x%x",
+	      req->type);
+	    *reply = -EINVAL;
+    }
+    return sizeof(int);
+}
+
+
+static void recv_unix(void)
+{
+    struct atmarp_req req;
+
+    if (un_reply(unix_sock,&req,sizeof(req),got_unix,NULL) < 0)
+	diag(COMPONENT,DIAG_ERROR,"un_reply: %s",strerror(errno));
+}
+
+
+static void close_unix(void)
+{
+    (void) close(unix_sock);
+    (void) unlink(ATMARP_SOCKET_PATH);
+}
+
+
 /* ----- common part ------------------------------------------------------- */
 
 
@@ -357,8 +387,11 @@ void poll_loop(void)
 	FD_ZERO(&rset);
 	FD_ZERO(&cset);
 	FD_SET(kernel,&rset);
+	FD_SET(unix_sock,&rset);
 	if (incoming >= 0) FD_SET(incoming,&rset);
-	fds = (kernel > incoming ? kernel : incoming)+1;
+	fds = incoming+1;
+	if (kernel >= fds) fds = kernel+1;
+	if (unix_sock >= fds) fds = unix_sock+1;
 	for (itf = itfs; itf; itf = itf->next)
 	    for (entry = itf->table; entry; entry = entry->next)
 		for (vcc = entry->vccs; vcc; vcc = vcc->next) {
@@ -403,6 +436,7 @@ void poll_loop(void)
 	    diag(COMPONENT,DIAG_DEBUG,"----------");
 	    gettimeofday(&now,NULL);
 	    if (FD_ISSET(kernel,&rset)) recv_kernel();
+	    if (FD_ISSET(unix_sock,&rset)) recv_unix();
 	    if (incoming >= 0 && FD_ISSET(incoming,&rset)) accept_new();
 	    for (itf = itfs; itf; itf = next_itf) {
 		next_itf = itf->next;
@@ -424,7 +458,7 @@ void poll_loop(void)
 	      /* expire timers after handling messages to make sure we don't
 		 time out unnecessarily because of scheduling delays */
 	}
-	dump_all();
+	table_changed();
     }
 }
 
@@ -486,3 +520,17 @@ int get_local(int fd,struct sockaddr_atmsvc *addr)
 	diag(COMPONENT,DIAG_ERROR,"getsockname: %s",strerror(errno));
     return result;
 }
+
+
+void open_all(void)
+{
+    open_kernel();
+    open_unix();
+}
+
+
+void close_all(void)
+{
+    close_kernel();
+    close_unix();
+}
