@@ -7,16 +7,12 @@
 #define TABLE_H
 
 #include <stdint.h>
+#include <stdio.h>
 #include <linux/atm.h>
 
 #include "atmd.h"
 
 
-#define DUMP_DIR	"/var/run"
-#define DUMP_FILE	"atmarpd.table"
-#define TMP_DUMP_FILE	"~atmarpd.table"
-
-
 typedef struct _vcc {
     int connecting;
     int active; /* indicate direction - for user entertainment only */
@@ -80,6 +76,7 @@ ENTRY *lookup_ip(const ITF *itf,uint32_t ip);
 ENTRY *lookup_addr(const ITF *itf,const struct sockaddr_atmsvc *addr);
 ENTRY *lookup_incoming(const struct sockaddr_atmsvc *addr);
 
-void dump_all(void);
+void table_changed(void);
+int table_update(void);
 
 #endif
