@@ -114,7 +114,8 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
     diag(COMPONENT, DIAG_FATAL, "ioctl ATM_GETADDR: %s", strerror(errno));
 
   n = 0;
-  if (req.length && atm_equal(&addr, &ouraddr[0], ATM_ESA_LEN, 0)) {
+  if (req.length && atm_equal((struct sockaddr *) &addr,
+   (struct sockaddr *) &ouraddr[0], ATM_ESA_LEN, 0)) {
     diag(COMPONENT, DIAG_INFO, "Primary ATM Address did not change");
     n = 1;
   }
