@@ -38,7 +38,7 @@ void dump_error(const Unit_t *unit, const char *msg);
 void dump_addr(const LaneDestination_t *addr);
 void dump_atmaddr(const AtmAddr_t *addr);
 void dump_control(const LaneControl_t *c);
-void disp_sockaddr(struct sockaddr_atmsvc *addr);
+void disp_sockaddr(struct sockaddr_atmsvc *addr, struct atm_blli *blli);
 
 /* Global data */
 extern const Unit_t dump_unit;
