@@ -171,7 +171,7 @@ exit_handler(const Event_t *event, void *funcdata)
 static void
 parse_args(int argc, char **argv)
 {
-  int i;
+  int i = 0;
   const Unit_t *unit, **units;
   
   progname = argv[0];
