@@ -37,7 +37,6 @@
 #include <stdlib.h>  /* for malloc() and free() */
 /* Atm includes */
 #include <linux/atm.h>
-#include <linux/atmdev.h>
 #include <linux/atmlec.h>
 
 /* Local includes */
@@ -50,7 +49,6 @@
 #include "emask.h"
 
 /* Local vars */
-extern int errno;
 static int lec_socket;
 /* Callback func array */
 static kernel_callback callback_funcs[ATMLEC_MSG_TYPE_MAX];
