@@ -10,6 +10,19 @@
 #include <linux/atm.h>
 
 
+/*
+ * For glibc. gcc won't complain unless we define something else than what
+ * is in sys/socket.h
+ */
+
+#define AF_ATMPVC	20
+#define AF_ATMSVC	21
+#define PF_ATMPVC	AF_ATMPVC
+#define PF_ATMSVC	AF_ATMSVC
+#define SOL_ATM		264
+#define SOL_AAL		265
+
+
 #define HOSTS_ATM "/etc/hosts.atm"
 
 /* text2atm flags */
@@ -30,7 +43,7 @@
 
 /* atm_equal flags */
 #define AXE_WILDCARD	 1	/* allow wildcard match */
-#define AXE_PRVOPT	 2	/* private part is optional */
+#define AXE_PRVOPT	 2	/* private part of SVC address is optional */
 
 /* text2qos flags */
 #define T2Q_DEFAULTS	 1	/* structure contains default values */
@@ -61,8 +74,8 @@ int create_leaf(int session);
 
 int text2atm(const char *text,struct sockaddr *addr,int length,int flags);
 int atm2text(char *buffer,int length,const struct sockaddr *addr,int flags);
-int atm_equal(const struct sockaddr_atmsvc *a,const struct sockaddr_atmsvc *b,
-  int len,int flags);
+int atm_equal(const struct sockaddr *a,const struct sockaddr *b,int len,
+  int flags);
 
 int sdu2cell(int s,int sizes,const int *sdu_size,int *num_sdu);
 
