@@ -1,6 +1,6 @@
 /* diag.c - Diagnostic messages */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -12,7 +12,8 @@
 #include "atmd.h"
 
 
-#define MAX_DIAG_MSG 8200
+#define MAX_DIAG_MSG  8200
+#define DUMP_LINE_WIDTH 75
 
 
 typedef struct _component {
@@ -78,7 +79,7 @@ void set_logfile(const char *name)
 	(void) fclose(log_to);
 	log_to = stderr;
     }
-    if (!name) {
+    if (!name || !strcmp(name,"stderr")) {
 	log_to = stderr;
 	return;
     }
@@ -149,3 +150,27 @@ void diag(const char *component,int severity,const char *fmt,...)
     vdiag(component,severity,fmt,ap);
     va_end(ap);
 }
+
+
+void diag_dump(const char *component,int severity,const char *title,
+  const unsigned char *data,int len)
+{
+    char buffer[DUMP_LINE_WIDTH+1];
+    char *curr;
+    int data_line,left;
+
+    if (title) diag(component,severity,"%s (%d bytes)\n",title,len);
+    data_line = DUMP_LINE_WIDTH-(app_name ? strlen(app_name)+1 : 0)-
+      strlen(component)-3;
+    while (len) {
+	left = data_line;
+	curr = buffer;
+	while (len && left >= 3) {
+	    sprintf(curr," %02x",*data++);
+	    len--;
+	    curr += 3;
+	    left -= 3;
+	}
+	diag(component,severity,"%s ",buffer);
+    }
+}
