@@ -114,8 +114,8 @@ static void to_tcp(void)
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"%s [ -b ] -l [ <lclport> ]\n",name);
-    fprintf(stderr,"%s [ -b ] -c <host> [ <rmtport> ]\n",name);
+    fprintf(stderr,"%s [ -b ] [ -i itf ] -l [ <lclport> ]\n",name);
+    fprintf(stderr,"%s [ -b ] [ -i itf ] -c <host> [ <rmtport> ]\n",name);
     exit(1);
 }
 
@@ -129,10 +129,24 @@ int main(int argc,char **argv)
 
     name = argv[0];
     background = 0;
-    if (argc > 2 && !strcmp(argv[1],"-b")) {
-	background = 1;
-	argc--;
-	argv++;
+    itf = -1;
+    while (argc > 2) {
+	if (!strcmp(argv[1],"-b")) {
+	    if (background) usage(name);
+	    background = 1;
+	    argc--;
+	    argv++;
+        }
+	else if (!strcmp(argv[1],"-i")) {
+	    char *end;
+
+	    if (itf != -1) usage(name);
+	    itf = strtoul(argv[2],&end,10);
+	    if (*end) usage(name);
+	    argc -= 2;
+	    argv += 2;
+        }
+	else break;
     }
     if (argc < 2) usage(name);
     listen_mode = !strcmp(argv[1],"-l");
@@ -159,7 +173,7 @@ int main(int argc,char **argv)
 	perror("socket");
 	return 1;
     }
-    if ((itf = ioctl(s_krn,SIOCSIFATMTCP,0)) < 0) {
+    if ((itf = ioctl(s_krn,SIOCSIFATMTCP,itf)) < 0) {
 	perror("ioctl SIOCSIFATMTCP");
 	return 1;
     }
