@@ -1,6 +1,6 @@
 /* io.h - I/O operations */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef IO_H
@@ -25,8 +25,7 @@ extern struct sockaddr_atmpvc signaling_pvc;
 
 
 int open_all(void);
-void open_input(const char *name);
-void open_output(const char *name);
+void open_unix(const char *name);
 void init_current_time(void);
 void poll_loop(void);
 void close_all(void);
