@@ -206,8 +206,10 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		LOCAL_ADDR *walk;
 
 		for (walk = local_addr; walk->state != ls_unused; walk++)
-		    if (walk->state == ls_same && atm_equal(&walk->addr,
-		      &msg->svc,(ATM_ESA_LEN-1)*8,AXE_WILDCARD)) break;
+		    if (walk->state == ls_same &&
+		      atm_equal((struct sockaddr *) &walk->addr,
+		      (struct sockaddr *) &msg->svc,(ATM_ESA_LEN-1)*8,
+		      AXE_WILDCARD)) break;
 		    if(*msg->svc.sas_addr.pub)
 			diag(COMPONENT,DIAG_DEBUG,"binding to E.164 address "
 			  "%s\n",msg->svc.sas_addr.pub);
@@ -370,10 +372,8 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		    diag(COMPONENT,DIAG_FATAL,"No CI allocator (use -A)");
 		return;
 	    }
-	    if (net && allocate_ci) {
+	    if (net && allocate_ci)
 		diag(COMPONENT,DIAG_FATAL,"CI allocation role conflict");
-		return;
-	    }
 	    sock->pvc = msg->pvc;
 	    if (send_call_proceeding(sock))
 		diag(COMPONENT,DIAG_FATAL,"s_c_p failed");
