@@ -53,7 +53,8 @@ int sap_compat(const struct sockaddr_atmsvc *old_addr,
   struct atm_sap *res_sap,const struct atm_qos *old_qos,
   const struct atm_qos *new_qos,struct atm_qos *res_qos)
 {
-    if (atmsvc_addr_in_use(*old_addr) && !atm_equal(old_addr,new_addr,0,0))
+    if (atmsvc_addr_in_use(*old_addr) &&
+      !atm_equal((struct sockaddr *) old_addr,(struct sockaddr *) new_addr,0,0))
 	return 0;
     if (res_qos) *res_qos = *new_qos;
     if (old_qos->txtp.max_sdu && new_qos->rxtp.max_sdu &&
