@@ -51,6 +51,7 @@ int send_call_proceeding(SOCKET *sock)
 	    (void) q_close(&dsc);
 	    return vci;
 	}
+	sock->pvc.sap_family = AF_ATMPVC;
 	sock->pvc.sap_addr.itf = signaling_pvc.sap_addr.itf;
 	sock->pvc.sap_addr.vpi = 0;
 	sock->pvc.sap_addr.vci = vci;
@@ -115,6 +116,7 @@ static void setup_call(unsigned long call_ref)
 	int vpci;
 
 	vpci = q_fetch(&in_dsc,QF_vpi);
+	this->pvc.sap_family = AF_ATMPVC;
 	this->pvc.sap_addr.itf = get_itf(&vpci);
 	this->pvc.sap_addr.vpi = vpci;
 	this->pvc.sap_addr.vci = q_fetch(&in_dsc,QF_vci);
@@ -238,7 +240,7 @@ static void send_restart_ack(int vpi,int vci)
     q_assign(&dsc,QF_call_ref,0);
     if (!vpi && !vci) q_assign(&dsc,QF_rst_class,ATM_RST_ALL_VC);
     else {
-	q_assign(&dsc,QF_rst_class,ATM_RST_ALL_VC);
+	q_assign(&dsc,QF_rst_class,ATM_RST_IND_VC);
 	q_assign(&dsc,QF_vpi,vpi);
 	q_assign(&dsc,QF_vci,vci);
     }
@@ -318,6 +320,7 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 		int vpci;
 
 		vpci = q_fetch(&in_dsc,QF_vpi);
+		sock->pvc.sap_family = AF_ATMPVC;
 		sock->pvc.sap_addr.itf = get_itf(&vpci);
 		sock->pvc.sap_addr.vpi = vpci;
 		sock->pvc.sap_addr.vci = q_fetch(&in_dsc,QF_vci);
@@ -339,6 +342,7 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 		int vpci;
 
 		vpci = q_fetch(&in_dsc,QF_vpi);
+		sock->pvc.sap_family = AF_ATMPVC;
 		sock->pvc.sap_addr.itf = get_itf(&vpci);
 		sock->pvc.sap_addr.vpi = vpci;
 		sock->pvc.sap_addr.vci = q_fetch(&in_dsc,QF_vci);
@@ -531,6 +535,7 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 		int vpci;
 
 		vpci = q_fetch(&in_dsc,QF_vpi);
+		sock->pvc.sap_family = AF_ATMPVC;
 		sock->pvc.sap_addr.itf = get_itf(&vpci);
 		sock->pvc.sap_addr.vpi = vpci;
 		sock->pvc.sap_addr.vci = q_fetch(&in_dsc,QF_vci);
@@ -633,6 +638,27 @@ void saal_okay(void)
     SOCKET *curr;
 
     trace_msg("SAAL came up");
+#ifdef THOMFLEX
+    /*
+     * Some versions of the Thomson Thomflex 5000 won't do any signaling before
+     * they get a RESTART. Whenever SAAL comes up, this may indicate that the
+     * switch got booted, so we send that RESTART. We also have to clear all
+     * pending connections, which isn't that nice ... Note that the rest of the
+     * RESTART state machine is not implemented, so the RESTART ACKNOWLEDGE
+     * will yield a warning.
+     */
+    {
+	Q_DSC dsc;
+	int size;
+
+	clear_all_calls();
+	q_create(&dsc,q_buffer,MAX_Q_MSG);
+	q_assign(&dsc,QF_msg_type,QMSG_RESTART);
+	q_assign(&dsc,QF_call_ref,0);
+	q_assign(&dsc,QF_rst_class,ATM_RST_ALL_VC);
+	if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
+    }
+#endif
     if (!t309) return;
     stop_timer(t309);
     t309 = NULL;
